==> apache-iotdb-2.0.3-source-release.zip: apache-iotdb-2.0.3/iotdb-core/node-commons/src/main/java/org/apache/iotdb/commons/schema/table/TableNodeStatus.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.commons.schema.table;

import org.apache.tsfile.utils.ReadWriteIOUtils;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public enum TableNodeStatus {
  PRE_CREATE((byte) 0),

  USING((byte) 1),

  PRE_DELETE((byte) 2);

  private final byte status;

  TableNodeStatus(final byte status) {
    this.status = status;
  }

  public void serialize(final OutputStream outputStream) throws IOException {
    ReadWriteIOUtils.write(status, outputStream);
  }

  public static TableNodeStatus deserialize(final InputStream inputStream) throws IOException {
    switch (ReadWriteIOUtils.readByte(inputStream)) {
      case 0:
        return PRE_CREATE;
      case 1:
        return USING;
      case 2:
        return PRE_DELETE;
      default:
        throw new IllegalArgumentException();
    }
  }
}

==> apache-iotdb-2.0.6-source-release.zip: apache-iotdb-2.0.6/iotdb-core/node-commons/src/main/java/org/apache/iotdb/commons/schema/table/TableNodeStatus.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.commons.schema.table;

import org.apache.tsfile.utils.ReadWriteIOUtils;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;

public enum TableNodeStatus {
  PRE_CREATE((byte) 0),

  USING((byte) 1),

  PRE_DELETE((byte) 2);

  private final byte status;

  TableNodeStatus(final byte status) {
    this.status = status;
  }

  public void serialize(final OutputStream outputStream) throws IOException {
    ReadWriteIOUtils.write(status, outputStream);
  }

  public static TableNodeStatus deserialize(final InputStream inputStream) throws IOException {
    switch (ReadWriteIOUtils.readByte(inputStream)) {
      case 0:
        return PRE_CREATE;
      case 1:
        return USING;
      case 2:
        return PRE_DELETE;
      default:
        throw new IllegalArgumentException();
    }
  }

  public static TableNodeStatus deserialize(final ByteBuffer buffer) {
    switch (ReadWriteIOUtils.readByte(buffer)) {
      case 0:
        return PRE_CREATE;
      case 1:
        return USING;
      case 2:
        return PRE_DELETE;
      default:
        throw new IllegalArgumentException();
    }
  }
}
